/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author:Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.compiler.gnu;

import static org.objectweb.fractal.cecilia.adl.compiler.ExecutionHelper.exec;

import java.io.File;
import java.util.Collection;

import org.objectweb.fractal.adl.util.Printer;
import org.objectweb.fractal.cecilia.adl.compiler.AbstractLinkTask;
import org.objectweb.fractal.cecilia.adl.compiler.CompilationException;

public class GnuLinkerTask extends AbstractLinkTask {

  protected final String ldCommand;

  // ---------------------------------------------------------------------------
  // Task constructor
  // ---------------------------------------------------------------------------

  /**
   * @param ldCommand the command of the Gnu linker to be executed by this task.
   * @param outputName the name of the linked file
   * @param outputDir the directory into which the compiled file will be placed.
   * @param flags compilation flags.
   */
  public GnuLinkerTask(final String ldCommand, final String outputName,
      final File outputDir, final String flags) {
    super(outputName, outputDir, flags);
    this.ldCommand = ldCommand;
  }

  // ---------------------------------------------------------------------------
  // Implementation of abstract methods of AbstractLinkTask
  // ---------------------------------------------------------------------------

  @Override
  protected void link(final File outputFile, final Collection<File> inputFiles)
      throws Exception {
    // forge command line.
    String commandLine = ldCommand + " " + flags + " -o "
        + outputFile.getCanonicalPath();

    for (final File inputFile : inputFiles) {
      commandLine += " " + inputFile.getCanonicalPath();
    }

    // print debug or info message.
    if (Printer.isDebugEnable())
      Printer.debug("[ld] " + commandLine);
    else if (Printer.isInfoEnable())
      Printer.info("[ld] " + outputFile.getPath());

    // execute command
    final int rValue = exec(commandLine);
    if (rValue != 0) {
      throw new CompilationException("Error while linking file \""
          + outputFile.getCanonicalPath() + "\"");
    }
  }
}
