
package org.objectweb.fractal.cecilia.adl.test;

import java.util.HashMap;
import java.util.Map;

import junit.framework.TestCase;

import org.objectweb.fractal.adl.Factory;
import org.objectweb.fractal.adl.FactoryFactory;
import org.objectweb.fractal.cecilia.adl.Launcher;
import org.objectweb.fractal.cecilia.adl.implementations.LanguageLoader;

/**
 * Test that arguments and attributes in LanguageLoader definition are correctly
 * defined.
 * 
 * @author Alessio Pace
 */
public class LanguageLoaderTest extends TestCase {

  public static final String DEFINITION = LanguageLoader.class
                                            .getCanonicalName();

  private Factory            factory;
  private Map                compilerContext;

  @Override
  public void setUp() throws Exception {
    /* get the bootstrap factory */
    this.factory = FactoryFactory.getFactory();

    this.compilerContext = new HashMap();
    this.compilerContext.put(LanguageLoader.DEFAULT_PPL_PROPERTY_NAME,
        LanguageLoader.DEFAULT_PPL);
    this.compilerContext.put(LanguageLoader.DEFAULT_CPL_PROPERTY_NAME,
        LanguageLoader.DEFAULT_CPL);
    this.compilerContext.put(LanguageLoader.DEFAULT_CPLS_PROPERTY_NAME,
        LanguageLoader.DEFAULT_CPLS);
    this.compilerContext.put(Launcher.PLUGIN_FACTORY_BACKEND_PROPERTY_NAME,
        Launcher.DEFAULT_PLUGIN_FACTORY_BACKEND);
  }

  public void testLoadingLanguageLoader() throws Exception {
    final LanguageLoader languageLoaderComponent = (LanguageLoader) this.factory
        .newComponent(DEFINITION, this.compilerContext);
    assertNotNull("Assert component not null", languageLoaderComponent);
  }

  public void testLoadingCeciliaLoader() throws Exception {
    final Object result = this.factory.newComponent(
        "org.objectweb.fractal.cecilia.adl.CeciliaLoader", this.compilerContext);
    assertNotNull("Assert result not null", result);
  }

  public void testLoadingCeciliaBasicFactory() throws Exception {
    final Object result = this.factory.newComponent(
        "org.objectweb.fractal.cecilia.adl.CeciliaBasicFactory", this.compilerContext);
    assertNotNull("Assert result not null", result);
  }

}
